@@ -1,4 +1,4 @@
-import CustomModel # seq2seq module
+import BaseModel # seq2seq module
 from Utils import * # other functions
 
 def model_only(sentence):
