@@ -21,7 +21,8 @@ def tokenizer(text):
   return list(text.split(" "))
 
 # 사전 로드
-loaded_dct = Dictionary.load_from_text("dictionary.txt")
+fn = pathlib.Path(__file__).parent / 'dictionary.txt'
+loaded_dct = Dictionary.load_from_text(fn)
 
 # 표기 오류가 있는 단어 indices, words return
 def check_error(word_list):
@@ -116,7 +117,8 @@ def seq2seq(text_list):
 
   return prediction_list
 
-default_word = pd.read_csv("clean_dataset.csv", names = ['num', 'words'])
+fn = pathlib.Path(__file__).parent / 'clean_dataset.csv'
+default_word = pd.read_csv(fn, names = ['num', 'words'])
 default_word = list(default_word['words'])[1:]
 
 # 빠른 Edit Distance 도출을 위한 indexer
